##########################################
Checks to support the Google Fonts profile
##########################################

Base checks
***********

.. automodule:: fontbakery.checks.googlefonts
    :members:

Axis registry checks
********************

.. automodule:: fontbakery.checks.googlefonts.axisregistry
    :members:

Color font checks
*****************

.. automodule:: fontbakery.checks.googlefonts.color
    :members:

Copyright checks
****************

.. automodule:: fontbakery.checks.googlefonts.copyright
    :members:

Description checks
******************

.. automodule:: fontbakery.checks.googlefonts.description
    :members:

Family checks
*************

.. automodule:: fontbakery.checks.googlefonts.family
    :members:

GDEF table checks
*****************

.. automodule:: fontbakery.checks.googlefonts.gdef
    :members:

glyf table checks
*****************

.. automodule:: fontbakery.checks.googlefonts.glyf
    :members:

Glyphset checks
***************

.. automodule:: fontbakery.checks.googlefonts.glyphset
    :members:

GPOS table checks
*****************

.. automodule:: fontbakery.checks.googlefonts.gpos
    :members:

GSUB table checks
*****************

.. automodule:: fontbakery.checks.googlefonts.gsub
    :members:

head table checks
*****************

.. automodule:: fontbakery.checks.googlefonts.head
    :members:

Hinting checks
**************

.. automodule:: fontbakery.checks.googlefonts.hinting
    :members:

Regressions checks against fonts hosted on fonts.google.com
***********************************************************

.. automodule:: fontbakery.checks.googlefonts.hosted
    :members:

License checks
**************

.. automodule:: fontbakery.checks.googlefonts.license
    :members:

meta table checks
*****************

.. automodule:: fontbakery.checks.googlefonts.meta
    :members:

Metadata checks
***************

.. automodule:: fontbakery.checks.googlefonts.metadata
    :members:

name table checks
*****************

.. automodule:: fontbakery.checks.googlefonts.name
    :members:

OS/2 table checks
*****************

.. automodule:: fontbakery.checks.googlefonts.os2
    :members:

Repository checks
*****************

.. automodule:: fontbakery.checks.googlefonts.repo
    :members:

STAT table checks
*****************

.. automodule:: fontbakery.checks.googlefonts.stat
    :members:

Subsetting checks
*****************

.. automodule:: fontbakery.checks.googlefonts.subsets
    :members:

Font table checks
*****************

.. automodule:: fontbakery.checks.googlefonts.tables
    :members:

Variable font checks
********************

.. automodule:: fontbakery.checks.googlefonts.varfont
    :members:

Vertical metrics checks
***********************

.. automodule:: fontbakery.checks.googlefonts.vmetrics
    :members: